searchNodes=[{"doc":"Builds GraphQL Documents from simple Elixir data structures. These functions take Elixir data in the same structure as GraphQL and return the analogous GraphQL Document as a String . GraphQLDocument.query/2 GraphQLDocument.mutation/2 GraphQLDocument.subscription/2 Using these abilities, developers can generate GraphQL queries programmatically. GraphQLDocument can be used to create higher-level DSL s for writing GraphQL queries. Getting Started Elixir &amp; GraphQL Code Snippets Each Elixir code snippet is immediately followed by the GraphQL that it will produce. All functions called in the code snippets below are in GraphQLDocument . ( import GraphQLDocument to directly use them.) Object Fields To request a list of fields in an object, include them in a list. query ( [ human : [ :name , :height ] ] ) query { human { name height } } Arguments Wrap arguments along with child fields in a tuple. { args , fields } query ( human : { [ id : &quot;1000&quot; ] , [ :name , :height ] } ) query { human(id: &quot;1000&quot;) { name height } } Argument types and Enums Elixir primitives (numbers, strings, lists, booleans, etc.) are translated into the analogous GraphQL primitive. Enums are expressed with atoms, like MY_ENUM , :MY_ENUM , or :&quot;MY_ENUM&quot; query ( human : { [ id : &quot;1000&quot; ] , [ :name , height : { [ unit : FOOT ] , [ ] } ] } ) query { human(id: &quot;1000&quot;) { name height(unit: FOOT) } } Expressing Arguments Without Sub-fields Notice the slightly complicated syntax above: height: {[unit: FOOT], []} Since args can be expressed in {args, fields} tuple, we put [] where the sub-fields go because there are no sub-fields. This can also be expressed as height: field(args: [unit: FOOT]) . See field/1 . Mixing Lists and Keyword Lists Since GraphQL supports a theoretically infinite amount of nesting, you can also nest as much as needed in the Elixir structure. Furthermore, we can take advantage of Elixir's syntax feature that allows a regular list to be &quot;mixed&quot; with a keyword list. (The keyword pairs must be at the end.) # Elixir allows lists with a Keyword List as the final members [ :name , :height , friends : [ :name , :age ] ] Using this syntax, we can build a nested structure where we select primitive fields (like :name below) alongside object fields (like :friends ). query ( human : { [ id : &quot;1000&quot; ] , [ :name , :height , friends : { [ olderThan : 30 ] , [ :name , :height ] } ] } ) query { human(id: &quot;1000&quot;) { name height friends(olderThan: 30) { name height } } } Variables To express a variable as a value, use {:var, var_name} syntax or the var/1 function. The variable definition is passed as an option to query/2 , mutation/2 , or subscription/2 . Variable types can take the form Int , {Int, null: false} , or {Int, default: 1} . query ( [ user : { [ id : var ( :myId ) ] , [ :name , friends : { [ type : { :var , :friendType } ] , [ :name ] } ] } ] , variables : [ myId : { Int , null : false } , friendType : { String , default : &quot;best&quot; } ] ) query ($myId: Int!, $friendType: String = &quot;best&quot;) { user(id: $myId) { name friends(type: $friendType) { name } } } Fragments To express a fragment, use the :... atom as the field name, similar to how you would in GraphQL. The fragment definition is passed as an option to query/2 , mutation/2 , or subscription/2 . Inline fragments and fragment definitions use the on/1 function to specify the type condition. query ( [ self : [ ... : { on ( User ) , [ skip : [ if : true ] ] , [ :password , :passwordHash ] } , friends : [ ... : :friendFields ] ] ] , fragments : [ friendFields : { on ( User ) , [ :id , :name , profilePic : field ( args : [ size : 50 ] ) ] } ] ) query { self { ... on User @skip(if: true) { password passwordHash } friends(first: 10) { ...friendFields } } } fragment friendFields on User { id name profilePic(size: 50) } Features That Require field() The field/1 and field/2 functions are required in order to express Aliases and Directives . Aliases Express an alias by putting the alias in place of the field name, and pass the field name as the first argument to field/2 . In the example below, me is the alias and user is the field. Spot the Keyword List args: and select: below are members of an &quot;invisible&quot; keyword list using Elixir's call syntax . query ( me : field ( :user , args : [ id : 100 ] , select : [ :name , :email ] ) ) query { me: user(id: 100) { name email } } Directives Express a directive by passing directives: to field/1 or field/2 . A directive can be a single name (as an atom or string) or a tuple in {name, args} format. query ( self : field ( directives : [ :debug , log : [ level : &quot;warn&quot; ] ] select : [ :name , :email ] ) ) query { self @debug @log(level: &quot;warn&quot;) { name email } } Not-yet-supported features GraphQLDocument does not currently have the ability to generate Type System definitions, although they technically belong in a Document.","ref":"GraphQLDocument.html","title":"GraphQLDocument","type":"module"},{"doc":"If you want to express a field with directives or an alias, you must use this function. See field/2 if you want to specify an alias. Examples iex&gt; field ( ...&gt; args : [ id : 2 ] , ...&gt; directives : [ :debug ] , ...&gt; select : [ :name ] ...&gt; ) { :field , [ args : [ id : 2 ] , directives : [ :debug ] , select : [ :name ] ] }","ref":"GraphQLDocument.html#field/1","title":"GraphQLDocument.field/1","type":"function"},{"doc":"If you want to express a field with an alias, you must use this function. Put the alias where you would normally put the field name, and pass the field name as the first argument to field/2 . See field/1 if you want to specify directives without an alias. Examples iex&gt; field ( ...&gt; :user , ...&gt; args : [ id : 2 ] , ...&gt; directives : [ :debug ] , ...&gt; select : [ :name ] ...&gt; ) { :field , :user , [ args : [ id : 2 ] , directives : [ :debug ] , select : [ :name ] ] }","ref":"GraphQLDocument.html#field/2","title":"GraphQLDocument.field/2","type":"function"},{"doc":"Generate a GraphQL mutation document. See the Getting Started section for more details. Example iex&gt; mutation ( ...&gt; registerUser : { ...&gt; [ ...&gt; name : &quot;Ben&quot; , ...&gt; hexUsername : &quot;benwilson512&quot; , ...&gt; packages : [ &quot;absinthe&quot; , &quot;ex_aws&quot; ] ...&gt; ] , ...&gt; [ ...&gt; :id , ...&gt; ] ...&gt; } ...&gt; ) &quot;&quot;&quot; mutation { registerUser(name: &quot;Ben&quot;, hexUsername: &quot;benwilson512&quot;, packages: [&quot;absinthe&quot;, &quot;ex_aws&quot;]) { id } } \\ &quot;&quot;&quot;","ref":"GraphQLDocument.html#mutation/2","title":"GraphQLDocument.mutation/2","type":"function"},{"doc":"Creates a TypeCondition for a Fragment . See GraphQLDocument.Fragment for more details. Example iex&gt; on ( User ) { :on , User }","ref":"GraphQLDocument.html#on/1","title":"GraphQLDocument.on/1","type":"function"},{"doc":"Generate a GraphQL query document. See the Getting Started section for more details. Example iex&gt; query ( ...&gt; [ ...&gt; customer : { [ id : var ( :customerId ) ] , [ ...&gt; :name , ...&gt; :email , ...&gt; phoneNumbers : field ( args : [ type : MOBILE ] ) , ...&gt; cartItems : [ ...&gt; :costPerItem , ...&gt; ... : :cartDetails ...&gt; ] ...&gt; ] } ...&gt; ] , ...&gt; variables : [ customerId : Int ] , ...&gt; fragments : [ cartDetails : { ...&gt; on ( CartItem ) , ...&gt; [ :sku , :description , :count ] ...&gt; } ] ...&gt; ) &quot;&quot;&quot; query ($customerId: Int) { customer(id: $customerId) { name email phoneNumbers(type: MOBILE) cartItems { costPerItem ...cartDetails } } } \\n fragment cartDetails on CartItem { sku description count } \\ &quot;&quot;&quot;","ref":"GraphQLDocument.html#query/2","title":"GraphQLDocument.query/2","type":"function"},{"doc":"Generate a GraphQL subscription document. Works like query/2 and mutation/2 , except that it generates a subscription. See the Getting Started section for more details.","ref":"GraphQLDocument.html#subscription/2","title":"GraphQLDocument.subscription/2","type":"function"},{"doc":"Wraps a variable name in a GraphQLDocument -friendly tuple. Example iex&gt; var ( :foo ) { :var , :foo }","ref":"GraphQLDocument.html#var/1","title":"GraphQLDocument.var/1","type":"function"},{"doc":"","ref":"GraphQLDocument.html#t:field_config/0","title":"GraphQLDocument.field_config/0","type":"type"},{"doc":"Arguments are specified in a keyword list. [ width : 100 , height : 50 ] See render/1 for examples of more complicated argument sets.","ref":"GraphQLDocument.Argument.html","title":"GraphQLDocument.Argument","type":"module"},{"doc":"Returns a list of Arguments as iodata to be inserted into a Document. Any valid GraphQL Value can be sent as the value of an Argument. (See GraphQLDocument.Value.t/0 .) Examples iex&gt; render ( height : 100 , width : 50 ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;(height: 100, width: 50)&quot; iex&gt; render ( name : &quot;Joshua&quot; , city : &quot;Montreal&quot; , friendsOfFriends : true ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;(name: \\&quot; Joshua \\&quot; , city: \\&quot; Montreal \\&quot; , friendsOfFriends: true)&quot; iex&gt; render ( %{ person : [ ...&gt; coordinates : [ ...&gt; lat : 123.45 , ...&gt; lng : 678.90 ...&gt; ] ...&gt; ] } ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;(person: {coordinates: {lat: 123.45, lng: 678.9}})&quot; iex&gt; render ( coordinates : [ ...&gt; lat : { :var , :myLat } , ...&gt; lng : { :var , :myLng } ...&gt; ] ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;(coordinates: {lat: $myLat, lng: $myLng})&quot; iex&gt; render ( ids : [ 1 , 2 , 3 ] ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;(ids: [1, 2, 3])&quot;","ref":"GraphQLDocument.Argument.html#render/1","title":"GraphQLDocument.Argument.render/1","type":"function"},{"doc":"A GraphQL argument.","ref":"GraphQLDocument.Argument.html#t:t/0","title":"GraphQLDocument.Argument.t/0","type":"type"},{"doc":"Directives provide a way to describe alternate runtime execution and type validation behavior in a GraphQL document. A Directive might be simply a name, or it can have arguments. See render/1 for examples.","ref":"GraphQLDocument.Directive.html","title":"GraphQLDocument.Directive","type":"module"},{"doc":"Returns a list of directives as iodata to be inserted into a Document. Examples iex&gt; render ( [ log : [ level : &quot;warn&quot; ] ] ) |&gt; IO . iodata_to_binary ( ) &quot; @log(level: \\&quot; warn \\&quot; )&quot; iex&gt; render ( [ :debug ] ) |&gt; IO . iodata_to_binary ( ) &quot; @debug&quot;","ref":"GraphQLDocument.Directive.html#render/1","title":"GraphQLDocument.Directive.render/1","type":"function"},{"doc":"A GraphQL directive. Examples :debug [ log : [ level : &quot;warn&quot; ] ]","ref":"GraphQLDocument.Directive.html#t:t/0","title":"GraphQLDocument.Directive.t/0","type":"type"},{"doc":"Enums can be defined in the Type System side of GraphQL. For the purposes of making GraphQL requests, you can express Enum Values as Values given in Arguments. Enums are expressed as atoms. You can use any valid atom syntax, such as Person or :Person or :&quot;Person&quot; . However, all enums must be valid GraphQL Names. See GraphQLDocument.Name . See render/1 for examples.","ref":"GraphQLDocument.Enum.html","title":"GraphQLDocument.Enum","type":"module"},{"doc":"Return an Enum as iodata to be inserted into a Document. Examples iex&gt; render ( User ) &quot;User&quot; iex&gt; render ( :User ) &quot;User&quot; iex&gt; render ( :user ) &quot;user&quot; iex&gt; render ( :_user ) &quot;_user&quot; iex&gt; render ( :__user__ ) &quot;__user__&quot; iex&gt; render ( :&quot;--user--&quot; ) ** (ArgumentError) --user-- is not a valid GraphQL name","ref":"GraphQLDocument.Enum.html#render/1","title":"GraphQLDocument.Enum.render/1","type":"function"},{"doc":"Enums are specified as atoms. They must be a valid GraphQL Name. (See GraphQLDocument.Name )","ref":"GraphQLDocument.Enum.html#t:t/0","title":"GraphQLDocument.Enum.t/0","type":"type"},{"doc":"A Field describes one discrete piece of information available to request within a selection set. Scalar fields (e.g. Ints, Booleans, and Strings) are requested by their name. :name :email Whereas object fields must be given with child fields as well. [ user : [ :name , email ] ]","ref":"GraphQLDocument.Field.html","title":"GraphQLDocument.Field","type":"module"},{"doc":"Allows you to specify a complex Field expression with Arguments, Directives, Selections, and an Alias.","ref":"GraphQLDocument.Field.html#new/1","title":"GraphQLDocument.Field.new/1","type":"function"},{"doc":"Returns a Field as iodata to be inserted into a Document. Examples iex&gt; render ( :email , 1 ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;email&quot; iex&gt; render ( { :self , [ :name , :email ] } , 1 ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;&quot;&quot; self { name email } \\ &quot;&quot;&quot; iex&gt; { :user , { :field , ...&gt; args : [ id : 100 ] , ...&gt; select : [ :name , :email ] ...&gt; } } ...&gt; |&gt; render ( 1 ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;&quot;&quot; user(id: 100) { name email } \\ &quot;&quot;&quot; iex&gt; { :user , { :field , ...&gt; args : [ id : 100 ] , ...&gt; directives : [ log : [ level : &quot;warn&quot; ] ] , ...&gt; select : [ :name , :email ] ...&gt; } } ...&gt; |&gt; render ( 1 ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;&quot;&quot; user(id: 100) @log(level: &quot;warn&quot;) { name email } \\ &quot;&quot;&quot; iex&gt; { :me , { :field , ...&gt; :user , ...&gt; args : [ id : 100 ] , ...&gt; directives : [ log : [ level : &quot;warn&quot; ] ] , ...&gt; select : [ :name , :email ] ...&gt; } } ...&gt; |&gt; render ( 1 ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;&quot;&quot; me: user(id: 100) @log(level: &quot;warn&quot;) { name email } \\ &quot;&quot;&quot;","ref":"GraphQLDocument.Field.html#render/2","title":"GraphQLDocument.Field.render/2","type":"function"},{"doc":"An expression of a field with an alias or directives.","ref":"GraphQLDocument.Field.html#t:spec/0","title":"GraphQLDocument.Field.spec/0","type":"type"},{"doc":"Fields can be expressed a number of different ways. If the field is a scalar type, provide a String or Atom : [ :id , :firstName , :lastName ] If the field is an object type, express it as a keyword list with either [fields] or {args, fields} as the value of each key: [ friends : { [ first : 10 ] , [ :name ] } , # with args birthday : [ :month , :day ] , # with sub-fields, but no args ] See render/2 for examples of how different Elixir expressions are rendered as GraphQL syntax.","ref":"GraphQLDocument.Field.html#t:t/0","title":"GraphQLDocument.Field.t/0","type":"type"},{"doc":"Fragments are the primary unit of composition in GraphQL. Fragments allow for the reuse of common repeated selections of fields, reducing duplicated text in the document. Inline Fragments can be used directly within a selection to condition upon a type condition when querying against an interface or union. See render_definitions/1 for details about rendering FragmentDefinitions . See render/2 for details about rendering a FragmentSpread or InlineFragment .","ref":"GraphQLDocument.Fragment.html","title":"GraphQLDocument.Fragment","type":"module"},{"doc":"Returns a FragmentSpread or InlineFragment as an iolist to be inserted in a Document. Fragment Spreads To express a Fragment Spread, provide the name of the fragment as an atom or string. If there are directives, provide a {name, directives} tuple. Examples iex&gt; render ( :friendFields , 1 ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;...friendFields&quot; iex&gt; render ( { :friendFields , [ skip : [ if : { :var , :antisocial } ] ] } , 1 ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;...friendFields @skip(if: $antisocial)&quot; Inline Fragments To express an Inline Fragment, provide an {{:on, Type}, selections} tuple. If there are directives, provide {{:on, Type}, directives, selections} . The {:on, Type} syntax can be substituted with GraphQLDocument.on/1 : on ( Type ) Examples iex&gt; render ( ...&gt; { ...&gt; :friendFields , ...&gt; [ include : [ if : { :var , :expanded } ] ] ...&gt; } , ...&gt; 1 ...&gt; ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;...friendFields @include(if: $expanded)&quot; iex&gt; render ( [ :foo , :bar ] , 1 ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;&quot;&quot; ... { foo bar } \\ &quot;&quot;&quot; iex&gt; render ( { [ log : [ level : &quot;warn&quot; ] ] , [ :foo , :bar ] } , 1 ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;&quot;&quot; ... @log(level: &quot;warn&quot;) { foo bar } \\ &quot;&quot;&quot; iex&gt; render ( ...&gt; { ...&gt; { :on , Person } , ...&gt; [ :name , friends : [ :name , :city ] ] ...&gt; } , ...&gt; 1 ...&gt; ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;&quot;&quot; ... on Person { name friends { name city } } \\ &quot;&quot;&quot; iex&gt; render ( ...&gt; { ...&gt; { :on , Person } , ...&gt; [ :log ] , ...&gt; [ :name , friends : [ :name , :city ] ] ...&gt; } , ...&gt; 1 ...&gt; ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;&quot;&quot; ... on Person @log { name friends { name city } } \\ &quot;&quot;&quot;","ref":"GraphQLDocument.Fragment.html#render/2","title":"GraphQLDocument.Fragment.render/2","type":"function"},{"doc":"Returns the given fragment definitions as iodata to be rendered in a GraphQL document. Examples iex&gt; render_definitions ( friendFields : { ...&gt; { :on , User } , ...&gt; [ :id , :name , profilePic : { [ size : 50 ] , [ ] } ] ...&gt; } ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;&quot;&quot; \\n \\n fragment friendFields on User { id name profilePic(size: 50) } \\ &quot;&quot;&quot;","ref":"GraphQLDocument.Fragment.html#render_definitions/1","title":"GraphQLDocument.Fragment.render_definitions/1","type":"function"},{"doc":"These are given in the fragments key of the Operation options. (See GraphQLDocument.Operation.option/0 .) This is not the usage of the Fragment (in a Selection set) but rather defining to be used in the rest of the Document. Examples GraphQLDocument . query ( [ ... ] , fragments : [ friendFields : { on ( User ) , [ :id , :name , profilePic : field ( args : [ size : 50 ] ) ] } ] )","ref":"GraphQLDocument.Fragment.html#t:definition/0","title":"GraphQLDocument.Fragment.definition/0","type":"type"},{"doc":"An inline fragment is a fragment that doesn't have a definition; the definition appears right in the middle of a selection set in the query/mutation/subscription. It exists to support requesting certain fields only if the object is a certain type (for objects of a union type), or to apply directives to only a subset of fields.","ref":"GraphQLDocument.Fragment.html#t:inline/0","title":"GraphQLDocument.Fragment.inline/0","type":"type"},{"doc":"The name of a fragment. An atom or string.","ref":"GraphQLDocument.Fragment.html#t:name/0","title":"GraphQLDocument.Fragment.name/0","type":"type"},{"doc":"A fragment spread is injecting ...fragmentName into a request to instruct the server to return the fields in the fragment. Fragment spreads are expressed with the :... atom to match GraphQL syntax. They are often inserted among other fields as in ...: :friendFields below. GraphQLDocument . query ( [ self : [ :name , :email , ... : :friendFields ] ] , fragments : [ friendFields : { ... } ] )","ref":"GraphQLDocument.Fragment.html#t:spread/0","title":"GraphQLDocument.Fragment.spread/0","type":"type"},{"doc":"","ref":"GraphQLDocument.Fragment.html#t:t/0","title":"GraphQLDocument.Fragment.t/0","type":"type"},{"doc":"The type to which the fragment applies. {:on, Person} is rendered as &quot;on Person&quot; . Instead of using {:on, type} tuples directly, you can use GraphQLDocument.on/1 : iex&gt; import GraphQLDocument iex&gt; on ( Person ) { :on , Person }","ref":"GraphQLDocument.Fragment.html#t:type_condition/0","title":"GraphQLDocument.Fragment.type_condition/0","type":"type"},{"doc":"The GraphQL specification defines a Name as starting with a letter or underscore. It may only contain letters, underscores, and digits. The names of Fields , Types , Arguments , Variables , Directives , Fragments , and Enums must all conform to this definition.","ref":"GraphQLDocument.Name.html","title":"GraphQLDocument.Name","type":"module"},{"doc":"Returns a Name as a string to be inserted into a Document. Raises an ArgumentError if the name doesn't start with a letter or underscore, or if it contains any characters other than letters, underscores, or digits. Examples iex&gt; render! ( &quot;_QuiGonJinn&quot; ) &quot;_QuiGonJinn&quot; iex&gt; render! ( ObiWan ) &quot;ObiWan&quot; iex&gt; render! ( :DinDjarin ) &quot;DinDjarin&quot; iex&gt; render! ( :leia_organa ) &quot;leia_organa&quot; iex&gt; render! ( &quot;0_StartingDigit&quot; ) ** (ArgumentError) 0_StartingDigit is not a valid GraphQL name iex&gt; render! ( &quot;_Qui-Gon Jinn&quot; ) ** (ArgumentError) _Qui-Gon Jinn is not a valid GraphQL name iex&gt; render! ( &quot;*;-!&quot; ) ** (ArgumentError) *;-! is not a valid GraphQL name","ref":"GraphQLDocument.Name.html#render!/1","title":"GraphQLDocument.Name.render!/1","type":"function"},{"doc":"A Name can be expressed as an atom or string.","ref":"GraphQLDocument.Name.html#t:t/0","title":"GraphQLDocument.Name.t/0","type":"type"},{"doc":"An Operation is a query, mutation, or subscription.","ref":"GraphQLDocument.Operation.html","title":"GraphQLDocument.Operation","type":"module"},{"doc":"Generates GraphQL syntax from a nested Elixir keyword list. Example iex&gt; render ( :query , ...&gt; user : { [ id : 3 ] , [ ...&gt; :name , ...&gt; :age , ...&gt; :height , documents : [ :filename , :url ] ] } ) ...&gt; documents : [ ...&gt; :filename , :url ] ] } ) ...&gt; :url ] ] } ) ...&gt; ] ] } ) ...&gt; ] } ...&gt; ) &quot;&quot;&quot; query { user(id: 3) { name age height documents { filename url } } } \\ &quot;&quot;&quot;","ref":"GraphQLDocument.Operation.html#render/3","title":"GraphQLDocument.Operation.render/3","type":"function"},{"doc":"","ref":"GraphQLDocument.Operation.html#t:operation_type/0","title":"GraphQLDocument.Operation.operation_type/0","type":"type"},{"doc":"Options that can be passed along with the operation. variables : See GraphQLDocument.Variable.definition/0 fragments : See GraphQLDocument.Fragment.definition/0 directives : See GraphQLDocument.Directive.t/0 Example GraphQLDocument . query ( [ ... ] , variables : [ postId : { Int , null : false } , commentType : String ] , fragments : [ friendFields : { on ( User ) , [ :id , :name , profilePic : field ( args : [ size : 50 ] ) ] } ] , directives : [ :debug [ log : [ level : &quot;warn&quot; ] ] ] )","ref":"GraphQLDocument.Operation.html#t:option/0","title":"GraphQLDocument.Operation.option/0","type":"type"},{"doc":"A Selection is the list of Fields or Fragments to be returned in an object.","ref":"GraphQLDocument.Selection.html","title":"GraphQLDocument.Selection","type":"module"},{"doc":"Returns the list of selections in a SelectionSet as iodata to be inserted into a Document. Examples iex&gt; render ( [ lightsaber : [ :color , :style ] ] , 1 ) |&gt; IO . iodata_to_binary ( ) &quot;&quot;&quot; { lightsaber { color style } } \\ &quot;&quot;&quot; iex&gt; render ( ...&gt; [ ...&gt; invoices : { ...&gt; [ customer : &quot;123456&quot; ] , ...&gt; [ ...&gt; :id , ...&gt; :total , ...&gt; items : ~w(description amount) , ...&gt; payments : { [ after : &quot;2021-01-01&quot; , posted : true ] , ~w(amount date) } ...&gt; ] ...&gt; } ...&gt; ] , ...&gt; 1 ...&gt; ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;&quot;&quot; { invoices(customer: \\&quot; 123456 \\&quot; ) { id total items { description amount } payments(after: \\&quot; 2021-01-01 \\&quot; , posted: true) { amount date } } } \\ &quot;&quot;&quot; iex&gt; render ( [ foo : :bar ] , 1 ) ** (ArgumentError) Expected a field; received {:foo, :bar} iex&gt; render ( [ foo : [ :bar ] ] , 0 ) ** (ArgumentError) indent_level must be at least 1; received 0","ref":"GraphQLDocument.Selection.html#render/2","title":"GraphQLDocument.Selection.render/2","type":"function"},{"doc":"","ref":"GraphQLDocument.Selection.html#t:t/0","title":"GraphQLDocument.Selection.t/0","type":"type"},{"doc":"A Type is a reference to a TypeDefinition defined by a GraphQL service. Types are used in GraphQLDocument when defining Variables. (See GraphQLDocument.Variable )","ref":"GraphQLDocument.Type.html","title":"GraphQLDocument.Type","type":"module"},{"doc":"Returns a Type as an iolist to be inserted into a Document. Examples iex&gt; render ( Int ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;Int&quot; iex&gt; render ( Boolean ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;Boolean&quot; iex&gt; render ( [ String ] ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;[String]&quot; iex&gt; render ( { Boolean , null : false } ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;Boolean!&quot; iex&gt; render ( { [ { Boolean , null : false } ] , null : false } ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;[Boolean!]!&quot;","ref":"GraphQLDocument.Type.html#render/1","title":"GraphQLDocument.Type.render/1","type":"function"},{"doc":"Options to be passed along with a Type. null - Whether it can be null","ref":"GraphQLDocument.Type.html#t:option/0","title":"GraphQLDocument.Type.option/0","type":"type"},{"doc":"A named type or a list type. Can be wrapped in a tuple to provide options, which are used to specify if it can be null. See render/1 for examples.","ref":"GraphQLDocument.Type.html#t:t/0","title":"GraphQLDocument.Type.t/0","type":"type"},{"doc":"A Value can be any of the following Elixir types: number boolean nil String List Map Atom (an Enum ; see GraphQLDocument.Enum ) {:var, var} (to represent a Variable ; see GraphQLDocument.Variable ) Values are sent inside Arguments (see GraphQLDocument.Argument ) or as default values in Variable Definitions (see GraphQLDocument.Variable.definition/0 ).","ref":"GraphQLDocument.Value.html","title":"GraphQLDocument.Value","type":"module"},{"doc":"Returns a Value as iodata to be inserted into a Document. Returns native Elixir date and datetime structures as strings in ISO8601 format. Examples iex&gt; render ( ~D[2019-11-12] ) &quot; \\&quot; 2019-11-12 \\&quot; &quot; iex&gt; render ( ~N[2019-11-12T10:30:25] ) &quot; \\&quot; 2019-11-12T10:30:25 \\&quot; &quot; iex&gt; render ( DateTime . from_naive! ( ~N[2019-11-12T10:30:25] , &quot;Etc/UTC&quot; ) ) &quot; \\&quot; 2019-11-12T10:30:25Z \\&quot; &quot; iex&gt; render ( Jedi ) &quot;Jedi&quot; iex&gt; render ( { :var , :allegiance } ) [ ?$ , &quot;allegiance&quot; ] iex&gt; render ( [ ] ) &quot;[]&quot; iex&gt; render ( &quot;sOmE-sTrInG&quot; ) &quot; \\&quot; sOmE-sTrInG \\&quot; &quot; iex&gt; render ( true ) &quot;true&quot; iex&gt; render ( false ) &quot;false&quot; iex&gt; render ( %{ map : %{ with : [ nested : [ &quot;data&quot; ] ] } } ) [ ?{ , [ [ &quot;map&quot; , ?: , 32 , [ ?{ , [ [ &quot;with&quot; , ?: , 32 , [ ?{ , [ [ &quot;nested&quot; , ?: , 32 , [ ?[ , [ &quot; \\&quot; data \\&quot; &quot; ] , ?] ] ] ] , ?} ] ] ] , ?} ] ] ] , ?} ] iex&gt; render ( %{ map : %{ with : [ nested : [ &quot;data&quot; ] ] } } ) |&gt; IO . iodata_to_binary ( ) &quot;{map: {with: {nested: [ \\&quot; data \\&quot; ]}}}&quot;","ref":"GraphQLDocument.Value.html#render/1","title":"GraphQLDocument.Value.render/1","type":"function"},{"doc":"","ref":"GraphQLDocument.Value.html#t:t/0","title":"GraphQLDocument.Value.t/0","type":"type"},{"doc":"Variables are defined in VariableDefinitions alongside the OperationType at the beginning of a GraphQL document. Any Variable that is defined in a Document can be used as the value of an Argument.","ref":"GraphQLDocument.Variable.html","title":"GraphQLDocument.Variable","type":"module"},{"doc":"Returns a Variable as iodata to be inserted into a Document. Examples iex&gt; render ( { :var , :expandedInfo } ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;$expandedInfo&quot; iex&gt; render ( { :var , &quot;username&quot; } ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;$username&quot; iex&gt; render ( { :var , &quot;&quot; } ) ...&gt; |&gt; IO . iodata_to_binary ( ) ** (ArgumentError) [empty string] is not a valid GraphQL name","ref":"GraphQLDocument.Variable.html#render/1","title":"GraphQLDocument.Variable.render/1","type":"function"},{"doc":"Returns Variable definitions as iodata to be inserted into a Document. Leading Space If any definitions are given, the returned iodata includes a leading space so that the output can be inserted into a Document either way and generate valid GraphQL syntax. Examples iex&gt; render_definitions ( [ ] ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot;&quot; iex&gt; render_definitions ( [ myInt : Int , debug : Boolean ] ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot; ($myInt: Int, $debug: Boolean)&quot; iex&gt; render_definitions ( lat : Float , lng : Float ) ...&gt; |&gt; IO . iodata_to_binary ( ) &quot; ($lat: Float, $lng: Float)&quot;","ref":"GraphQLDocument.Variable.html#render_definitions/1","title":"GraphQLDocument.Variable.render_definitions/1","type":"function"},{"doc":"These are given in the variables key of the Operation options. (See GraphQLDocument.Operation.option/0 .) This is not the usage of the Variable (as the Value of an Argument) but rather defining its Name and Type to be used in the rest of the Document. Examples GraphQLDocument . query ( [ ... ] , variables : [ yearOfBirth : Int , myId : { Int , null : false } , status : { String , default : &quot;active&quot; } , days : [ String ] , daysOfWeek : { [ String ] , default : [ &quot;Saturday&quot; , &quot;Sunday&quot; ] } ] )","ref":"GraphQLDocument.Variable.html#t:definition/0","title":"GraphQLDocument.Variable.definition/0","type":"type"},{"doc":"Options that can be passed when defining a variable. For the default option, pass any GraphQLDocument.Value.t/0 . See definition/0 for examples.","ref":"GraphQLDocument.Variable.html#t:option/0","title":"GraphQLDocument.Variable.option/0","type":"type"},{"doc":"Expresses the name of a Variable to be used as a Value (See GraphQLDocument.Value )","ref":"GraphQLDocument.Variable.html#t:t/0","title":"GraphQLDocument.Variable.t/0","type":"type"}]